#
# spec file for package ucblogo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ucblogo
Version:        6.2.4
Release:        bp156.1.5
Summary:        Berkeley Logo interpreter
License:        GPL-3.0-or-later
URL:            https://people.eecs.berkeley.edu/~bh/logo.html
Source:         https://github.com/jrincayc/ucblogo-code/releases/download/version_%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM ucblogo-wxString-to-c_str.patch badshah400@gmail.com -- Explicitly convert a wxString to c_string to match calling function's definition
Patch0:         ucblogo-wxString-to-c_str.patch
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  makeinfo
BuildRequires:  wxGTK3-devel
Recommends:     %{name}-doc = %{version}

%description
Berkeley Logo interpreter is a free (both senses) interpreter for the Logo
programming language.

%package doc
Summary:        Documentation for ucblogo - a free logo interpreter
BuildArch:      noarch

%description doc
This package provides additional documentation for ucblogo.

%prep
%autosetup -p1

%build
%configure --enable-docs \
           --docdir=%{_docdir}/%{name}
%make_build

%install
%make_install

%fdupes %{buildroot}%{_datadir}/%{name}/

%files
%license LICENSE
%doc README.md
%{_bindir}/ucblogo
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/pixmaps/*.xpm
%{_infodir}/%{name}.info%{?ext_info}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files doc
%doc %{_docdir}/%{name}/
%exclude %{_docdir}/%{name}/README.md

%changelog
* Sat Apr  1 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.2.4:
  * Validate RANDOM range input has the smaller number first
    (gh#jrincayc/ucblogo-code#151).
  * Manual updates (gh#jrincayc/ucblogo-code#152).
  * Avoid more implicit function declarations by @fweimer-rh in
    (gh#jrincayc/ucblogo-code#156).
  * Move wait include to else of windows.
    (gh#jrincayc/ucblogo-code#157).
  * Migrate to wxWidgets 3.2 (gh#jrincayc/ucblogo-code#163).
* Tue Jan 24 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.2.3:
  * Fix/standardize STANDOUT in wxWidgets builds
    (gh#jrincayc/ucblogo-code#122).
  * Refactor code so selection highlighting does not depend on
    platform supporting inverted blit mode.
    (gh#jrincayc/ucblogo-code#123).
  * Adding PRINT NOT "FALSE to show using quoted false.
    (gh#jrincayc/ucblogo-code#125).
  * Issue 126: Print preview on Windows
    (gh#jrincayc/ucblogo-code#128).
  * ISSUE-129: Remove obsolete macros from configure.ac
    (gh#jrincayc/ucblogo-code#131).
  * ISSUE-50: Indicate correct error line when GOTO has a
    nonexistent tag (gh#jrincayc/ucblogo-code#136).
  * ISSUE-134: Fixed issue with LOADPICT if it's called before
    other turtle commands (gh#jrincayc/ucblogo-code#135).
  * ISSUE-20: Resolving warnings about discarding const qualifier
    on assignment. (gh#jrincayc/ucblogo-code#141).
  * Fixes Stopping with repeat (gh#jrincayc/ucblogo-code#140).
  * Fix debug statements (gh#jrincayc/ucblogo-code#142).
* Sat Nov 26 2022 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- Add ucblogo-wxString-to-c_str.patch -- Explicitly convert a
  wxString to c_string to match calling function's definition
